@@ -70,6 +70,7 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_tenant').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_auth_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('keymgr/encryption_auth_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => '<SERVICE DEFAULT>')
       end
     end
 
@@ -190,7 +191,7 @@ describe 'cinder::api' do
       let :params do
         {
           :keystone_password => 'dummy',
-          :enabled           => 'true',
+          :enabled           => true,
           :sync_db           => false,
         }
       end
@@ -303,6 +304,37 @@ describe 'cinder::api' do
         )
       end
     end
+    describe 'when running cinder-api in wsgi' do
+      let :params do
+        req_params.merge!({ :service_name   => 'httpd' })
+      end
+
+      let :pre_condition do
+        "include ::apache
+         class { 'cinder': rabbit_password => 'secret' }"
+      end
+
+      it 'configures cinder-api service with Apache' do
+        is_expected.to contain_service('cinder-api').with(
+          :ensure     => 'stopped',
+          :enable     => false,
+          :tag        => ['cinder-service'],
+        )
+      end
+    end
+
+    describe 'when service_name is not valid' do
+      let :params do
+        req_params.merge!({ :service_name   => 'foobar' })
+      end
+
+      let :pre_condition do
+        "include ::apache
+         class { 'cinder': rabbit_password => 'secret' }"
+      end
+
+      it_raises 'a Puppet::Error', /Invalid service_name/
+    end
   end
 
   on_supported_os({
@@ -310,7 +342,11 @@ describe 'cinder::api' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({:processorcount => 8}))
+        facts.merge(OSDefaults.get_facts({
+          :processorcount => 8,
+          :fqdn           => 'some.host.tld',
+          :concat_basedir => '/var/lib/puppet/concat',
+        }))
       end
 
       it_configures 'cinder api'
